summaryrefslogtreecommitdiffstats
path: root/include
diff options
context:
space:
mode:
authorArun Kumar K.R <akkr@codeaurora.org>2012-03-16 19:18:01 -0700
committerGiulio Cervera <giulio.cervera@gmail.com>2012-05-02 12:47:00 +0200
commitb302db6f9a3ee89e48827812278d1425e82f2fdc (patch)
tree6a05e5c3e4b369c84c525e0f12dbdb701bff9908 /include
parent3f4a58e817e291c1ca01f5ff6f297a9123e49173 (diff)
downloadframeworks_base-b302db6f9a3ee89e48827812278d1425e82f2fdc.zip
frameworks_base-b302db6f9a3ee89e48827812278d1425e82f2fdc.tar.gz
frameworks_base-b302db6f9a3ee89e48827812278d1425e82f2fdc.tar.bz2
SurfaceFlinger: Handle WFD and HDMI concurrency.
- changes to handle wifi display and HDMI concurrency - rename enableHDMIOutput to enableExternalDisplay - remove action safe related functions(not used anymore) Change-Id: I15feb1309c2964de3deb968c334eb09e742afb6c
Diffstat (limited to 'include')
-rw-r--r--include/surfaceflinger/ISurfaceComposer.h10
-rw-r--r--include/surfaceflinger/SurfaceComposerClient.h8
2 files changed, 7 insertions, 11 deletions
diff --git a/include/surfaceflinger/SurfaceComposerClient.h b/include/surfaceflinger/SurfaceComposerClient.h
index 842a86b..3c7a022 100644
--- a/include/surfaceflinger/SurfaceComposerClient.h
+++ b/include/surfaceflinger/SurfaceComposerClient.h
@@ -110,13 +110,13 @@ public:
//! Open a composer transaction on all active SurfaceComposerClients.
static void openGlobalTransaction();
-
+
//! Close a composer transaction on all active SurfaceComposerClients.
static void closeGlobalTransaction(bool synchronous = false);
-
+
//! Freeze the specified display but not transactions.
static status_t freezeDisplay(DisplayID dpy, uint32_t flags = 0);
-
+
//! Resume updates on the specified display.
static status_t unfreezeDisplay(DisplayID dpy, uint32_t flags = 0);
@@ -137,7 +137,7 @@ public:
#ifdef QCOM_HDMI_OUT
//HDMI SPecific functions
- static void enableHDMIOutput(int enable);
+ static void enableExternalDisplay(int disp_type, int enable);
static void setActionSafeWidthRatio(float asWidthRatio);
static void setActionSafeHeightRatio(float asHeightRatio);
#endif
diff --git a/include/surfaceflinger/ISurfaceComposer.h b/include/surfaceflinger/ISurfaceComposer.h
index 2c60993..c96f88a 100644
--- a/include/surfaceflinger/ISurfaceComposer.h
+++ b/include/surfaceflinger/ISurfaceComposer.h
@@ -133,10 +133,8 @@ public:
const sp<ISurfaceTexture>& surface) const = 0;
#ifdef QCOM_HDMI_OUT
- //HDMI SPecific functions
- virtual void enableHDMIOutput(int enable) = 0;
- virtual void setActionSafeWidthRatio(float asWidthRatio) = 0;
- virtual void setActionSafeHeightRatio(float asHeightRatio) = 0;
+ //External display specific functions
+ virtual void enableExternalDisplay(int disp_type, int enable) = 0;
#endif
};
@@ -160,9 +158,7 @@ public:
TURN_ELECTRON_BEAM_ON,
AUTHENTICATE_SURFACE,
#ifdef QCOM_HDMI_OUT
- ENABLE_HDMI_OUTPUT,
- SET_ACTIONSAFE_WIDTH_RATIO,
- SET_ACTIONSAFE_HEIGHT_RATIO
+ EXTERNAL_DISPLAY,
#endif
};